==> haskell-hie-compat-0.2.0.0-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hie-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hie-compat
version:              0.2.0.0
visibility:           public
id:                   hie-compat-0.2.0.0-2uJ4eLp19m9HNuq0NixVNO
key:                  hie-compat-0.2.0.0-2uJ4eLp19m9HNuq0NixVNO
license:              Apache-2.0
maintainer:           zubin.duggal@gmail.com
author:               Zubin Duggal
synopsis:             HIE files for GHC 8.6 and other HIE file backports
description:
    Backports for HIE files to GHC 8.6, along with a few other backports
    of HIE file related fixes for ghcide.
    THIS DOES NOT LET YOU READ HIE FILES WITH MISMATCHED VERSIONS OF GHC

category:             Development
abi:                  97760d547a94e582e610883f16eed370
exposed:              True
exposed-modules:
    Compat.HieAst Compat.HieBin Compat.HieDebug Compat.HieTypes
    Compat.HieUtils

import-dirs:          /usr/lib/ghc-8.10.5/site-local/hie-compat-0.2.0.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/hie-compat-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.5/hie-compat-0.2.0.0
hs-libraries:         HShie-compat-0.2.0.0-2uJ4eLp19m9HNuq0NixVNO
depends:
    array-0.5.4.0 base-4.14.2.0 bytestring-0.10.12.0 containers-0.6.4.1
    directory-1.3.6.0 filepath-1.4.2.1 ghc-8.10.5 ghc-boot-8.10.5
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-hie-compat/html/hie-compat.haddock
haddock-html:         /usr/share/doc/haskell-hie-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hie-compat-0.2.0.0-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hie-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hie-compat
version:              0.2.0.0
visibility:           public
id:                   hie-compat-0.2.0.0-HHVbuGAk8zeLJ4sWoPjDO6
key:                  hie-compat-0.2.0.0-HHVbuGAk8zeLJ4sWoPjDO6
license:              Apache-2.0
maintainer:           zubin.duggal@gmail.com
author:               Zubin Duggal
synopsis:             HIE files for GHC 8.6 and other HIE file backports
description:
    Backports for HIE files to GHC 8.6, along with a few other backports
    of HIE file related fixes for ghcide.
    THIS DOES NOT LET YOU READ HIE FILES WITH MISMATCHED VERSIONS OF GHC

category:             Development
abi:                  910ab0fc2cd4ebf359115543c5d16ae3
exposed:              True
exposed-modules:
    Compat.HieAst Compat.HieBin Compat.HieDebug Compat.HieTypes
    Compat.HieUtils

import-dirs:          /usr/lib/ghc-9.0.1/site-local/hie-compat-0.2.0.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/hie-compat-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/hie-compat-0.2.0.0
hs-libraries:         HShie-compat-0.2.0.0-HHVbuGAk8zeLJ4sWoPjDO6
depends:
    array-0.5.4.0 base-4.15.0.0 bytestring-0.10.12.1 containers-0.6.4.1
    directory-1.3.6.1 filepath-1.4.2.1 ghc-9.0.1 ghc-boot-9.0.1
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-hie-compat/html/hie-compat.haddock
haddock-html:         /usr/share/doc/haskell-hie-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
